require 'test_helper'

module DailyRep
  ############################
  describe "Dailyrep testing" do

    before do
      @browser = IBrowser.new
      @browser.write_hist('test_entity_1', 'test_parameter', 'test_val')
      @browser.write_hist('test_entity_2', 'test_parameter', 'test_val', 1)
    end

    it 'should check database via check_ro_exists' do
      assert @browser.check_row_exists('test_entity_1', 'test_parameter', 'test_val')
    end
    it 'should perform http request to Dou.ua website' do
      assert @browser.get_source_http('http://jobs.dou.ua/vacancies/?search=Ruby', 'div#vacancyListId li')
    end

    it 'should perform json request to micex website' do
      assert @browser.get_source_json('http://www.micex.ru/issrpc/marketdata/currency/selt/daily/short/result.json?boardid=CETS&secid=USD000UTSTOM')
    end

    it 'should write history data to the database' do
      hist_1 = History.where(entity: 'test_entity_1').first
      hist_2 = History.where(entity: 'test_entity_2').first
      assert_equal 'N', hist_1.notified
      assert_equal 'Y', hist_2.notified
      assert_not hist_1.entity.empty?, 'entity column is empty'
      assert_not hist_1.parameter.empty?
      assert_not hist_1.val.empty?
      assert_not hist_1.created_at.empty?
      assert_not hist_1.id.nil?, 'Id has not been set'
    end

    it 'should check if notification exists in' do
      assert_nil @browser.check_history_notif('test_entity_1', 'test_parameter'), 'there should be no notifications'
      assert @browser.check_history_notif('test_entity_2', 'test_parameter')
    end

    it 'should check pushbullet connection' do
      client = Washbullet::Client.new(Configer.get_client_tokens.first)
      assert_not client.me.body["email"].empty?
    end
  end
end
